@@ -38,6 +38,7 @@
 #define PROPLUSX   0x4552
 #define VTX        0x4557
 #define I750TC     0x455A
+#define SAGE       0x4647
 #define I770R      0x4651
 #define GEO40      0x4653
 
@@ -491,6 +492,7 @@ static const oceanic_common_version_t versions[] = {
 	{"AER300CS \0\0 2048", 0,      &aeris_a300cs_layout},
 	{"OCEANVTX \0\0 2048", 0,      &aeris_a300cs_layout},
 	{"AQUAI750 \0\0 2048", 0,      &aeris_a300cs_layout},
+	{"SWDRAGON \0\0 2048", 0,      &aeris_a300cs_layout},
 
 	{"AQUAI450 \0\0 2048", 0,      &aqualung_i450t_layout},
 
@@ -902,7 +904,7 @@ oceanic_atom2_device_open (dc_device_t **out, dc_context_t *context, dc_iostream
 	}
 
 	if (dc_iostream_get_transport (device->iostream) == DC_TRANSPORT_BLE &&
-		model != PROPLUSX) {
+		model != PROPLUSX && model != SAGE ) {
 		status = oceanic_atom2_ble_handshake(device);
 		if (status != DC_STATUS_SUCCESS) {
 			goto error_free;
